@@ -142,13 +142,20 @@ def lift_sourcecode(value, filename="<unknown>"):
     """
     if not isinstance(value, str):
         raise TypeError(f"`n[]`: expected an expression that evaluates to str, result was {type(value)} with value {repr(value)}")
-    return ast.parse(value, filename=filename, mode="eval").body
+    return ast.parse(value, filename=f"<invocation of n[] in '{filename}'>", mode="eval").body
 
 
 def _typecheck(node, cls, macroname):
-    body = node.body if isinstance(node, ASTMarker) else node
-    if not isinstance(body, cls):
-        raise TypeError(f"{macroname}: expected an expression node, got {type(body)} with value {repr(body)}")
+    if isinstance(node, ASTMarker):
+        if isinstance(node.body, list):  # statement suite inside a marker
+            for child in node.body:
+                _typecheck(child, cls, macroname)
+            return
+        # single AST node inside a marker
+        _typecheck(node.body, cls, macroname)
+        return
+    if not isinstance(node, cls):
+        raise TypeError(f"{macroname}: expected {cls}, got {type(node)} with value {repr(node)}")
 
 def _flatten_and_typecheck_iterable(nodes, cls, macroname):
     try:
